@@ -24,7 +24,7 @@
 #ifndef GNOME_DISABLE_DEPRECATED_SOURCE
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include "gnome-dialog.h"
 #include <libgnome/gnome-util.h>
@@ -64,9 +64,9 @@ gnome_dialog_get_type (void)
 {
   static GType dialog_type = 0;
 
-  if (!dialog_type)
+  if (G_UNLIKELY (dialog_type == 0))
     {
-      static const GTypeInfo dialog_info =
+      const GTypeInfo dialog_info =
       {
 	sizeof (GnomeDialogClass),
         (GBaseInitFunc) NULL,
