@@ -24,6 +24,8 @@
 #ifndef __GNOME_DRUID_PAGE_EDGE_H__
 #define __GNOME_DRUID_PAGE_EDGE_H__
 
+#ifndef GNOME_DISABLE_DEPRECATED
+
 #include <gtk/gtk.h>
 #include <libgnomecanvas/gnome-canvas.h>
 #include "gnome-druid-page.h"
@@ -37,6 +39,20 @@ G_BEGIN_DECLS
 #define GNOME_IS_DRUID_PAGE_EDGE_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_DRUID_PAGE_EDGE))
 #define GNOME_DRUID_PAGE_EDGE_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), GNOME_TYPE_DRUID_PAGE_EDGE, GnomeDruidPageEdgeClass))
 
+/**
+ * GnomeEdgePosition:
+ * @GNOME_EDGE_START: The current page is at the beginning of the druid.
+ * @GNOME_EDGE_FINISH: The current page is at the end of the druid.
+ * @GNOME_EDGE_OTHER: The current page is neither the first nor the last page
+ * (usually not required).
+ * @GNOME_EDGE_LAST: Used internally to indicate the last value of the
+ * enumeration. This should not be passed in to any function expecting a
+ * #GnomeEdgePosition value.
+ *
+ * Used to pass around information about the position of a #GnomeDruidPage
+ * within the overall #GnomeDruid. This enables the correct "surrounding"
+ * content for the page to be drawn.
+ */
 typedef enum {
   /* update structure when adding enums */
 	GNOME_EDGE_START,
@@ -50,6 +66,25 @@ typedef struct _GnomeDruidPageEdge        GnomeDruidPageEdge;
 typedef struct _GnomeDruidPageEdgePrivate GnomeDruidPageEdgePrivate;
 typedef struct _GnomeDruidPageEdgeClass   GnomeDruidPageEdgeClass;
 
+/**
+ * GnomeDruidPageEdge:
+ * @title: The current title of the displayed page.
+ * @text: The current text of the displayed page.
+ * @logo_image: The logo of the displayed page.
+ * @watermark_image: The watermark on the left side of the displayed page.
+ * @top_watermark_image: The watermark on the top of the displayed page.
+ * @background_color: The color of the edge of the current page (outside the
+ * text area).
+ * @textbox_color: The color of the textbox area of the displayed page.
+ * @logo_background_color: The background color of the displayed page's logo.
+ * @title_color: The color of the title text.
+ * @text_color: The color of the body text.
+ * @position: The position of the current page within the druid (a
+ * #GnomeEdgePosition value).
+ *
+ * A widget holding information about the overall look of the currently
+ * displaying druid page.
+ */
 struct _GnomeDruidPageEdge
 {
 	GnomeDruidPage parent;
@@ -67,7 +102,7 @@ struct _GnomeDruidPageEdge
 	GdkColor title_color;
 	GdkColor text_color;
 
-	GnomeEdgePosition position : 2;
+	guint position : 2; /* GnomeEdgePosition */
 
 	/*< private >*/
 	GnomeDruidPageEdgePrivate *_priv;
@@ -76,6 +111,10 @@ struct _GnomeDruidPageEdge
 struct _GnomeDruidPageEdgeClass
 {
 	GnomeDruidPageClass parent_class;
+
+	/* Padding for possible expansion */
+	gpointer padding1;
+	gpointer padding2;
 };
 
 GType      gnome_druid_page_edge_get_type          (void) G_GNUC_CONST;
@@ -90,7 +129,7 @@ GtkWidget *gnome_druid_page_edge_new_with_vals     (GnomeEdgePosition   position
 						    GdkPixbuf	       *top_watermark);
 void       gnome_druid_page_edge_construct         (GnomeDruidPageEdge *druid_page_edge,
 						    GnomeEdgePosition   position,
-						    gboolean            antialiaed,
+						    gboolean            antialiased,
 						    const gchar        *title,
 						    const gchar        *text,
 						    GdkPixbuf          *logo,
@@ -115,8 +154,10 @@ void       gnome_druid_page_edge_set_logo          (GnomeDruidPageEdge *druid_pa
 void       gnome_druid_page_edge_set_watermark     (GnomeDruidPageEdge *druid_page_edge,
 						    GdkPixbuf          *watermark);
 void       gnome_druid_page_edge_set_top_watermark (GnomeDruidPageEdge *druid_page_edge,
-						    GdkPixbuf          *top_watermark);
+						    GdkPixbuf          *top_watermark_image);
 
 G_END_DECLS
 
+#endif /* GNOME_DISABLE_DEPRECATED */
+
 #endif /* __GNOME_DRUID_PAGE_EDGE_H__ */
