@@ -28,7 +28,7 @@
 #include <stdarg.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include "gnome-messagebox.h"
 
