@@ -35,6 +35,10 @@
 #include <string.h>
 #include <glib.h>
 #include <stdio.h>
+
+#define GDK_PIXBUF_ENABLE_BACKEND
+#include <gdk-pixbuf/gdk-pixbuf.h>
+
 #include <libgnome/gnome-macros.h>
 #include <libgnome/gnome-init.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -43,15 +47,8 @@
 #include "gnome-gconf-ui.h"
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-
 #include <glib/gstdio.h>
 
-#ifdef HAVE_LIBJPEG
-GdkPixbuf * _gnome_thumbnail_load_scaled_jpeg (const char *uri,
-					       int         target_width,
-					       int         target_height);
-#endif
-
 #define SECONDS_BETWEEN_STATS 10
 
 struct ThumbMD5Context {
@@ -88,7 +85,7 @@ struct ThumbnailInfo {
 
 GNOME_CLASS_BOILERPLATE (GnomeThumbnailFactory,
 			 gnome_thumbnail_factory,
-			 GObject, G_TYPE_OBJECT);
+			 GObject, G_TYPE_OBJECT)
 
 static void gnome_thumbnail_factory_instance_init (GnomeThumbnailFactory      *factory);
 static void gnome_thumbnail_factory_class_init    (GnomeThumbnailFactoryClass *class);
@@ -205,6 +202,12 @@ gnome_thumbnail_factory_finalize (GObject *object)
       g_hash_table_destroy (priv->scripts_hash);
       priv->scripts_hash = NULL;
     }
+
+  if (priv->lock)
+    {
+      g_mutex_free (priv->lock);
+      priv->lock = NULL;
+    }
   
   g_free (priv);
   factory->priv = NULL;
@@ -391,7 +394,7 @@ gnome_thumbnail_factory_instance_init (GnomeThumbnailFactory *factory)
   
   priv->scripts_hash = NULL;
   
-  factory->priv->lock = g_mutex_new ();
+  priv->lock = g_mutex_new ();
 
   gnome_thumbnail_factory_reread_scripts (factory);
 
@@ -444,7 +447,7 @@ gnome_thumbnail_factory_new (GnomeThumbnailSize size)
 static char *
 thumb_digest_to_ascii (unsigned char digest[16])
 {
-  static char hex_digits[] = "0123456789abcdef";
+  static const char hex_digits[] = "0123456789abcdef";
   char *res;
   int i;
   
@@ -933,13 +936,19 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
 					    const char            *uri,
 					    const char            *mime_type)
 {
-  GdkPixbuf *pixbuf, *scaled;
+  GdkPixbuf *pixbuf, *scaled, *tmp_pixbuf;
   char *script, *expanded_script;
   int width, height, size;
+  int original_width = 0;
+  int original_height = 0;
+  char dimension[12];
   double scale;
   int exit_status;
   char *tmpname;
 
+  g_return_val_if_fail (uri != NULL, NULL);
+  g_return_val_if_fail (mime_type != NULL, NULL);
+
   /* Doesn't access any volatile fields in factory, so it's threadsafe */
   
   size = 128;
@@ -959,7 +968,7 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
 
       fd = g_file_open_tmp (".gnome_thumbnail.XXXXXX", &tmpname, &error);
 
-      if (fd)
+      if (fd != -1)
 	{
 	  close (fd);
 
@@ -975,43 +984,68 @@ gnome_thumbnail_factory_generate_thumbnail (GnomeThumbnailFactory *factory,
 	  
 	  g_unlink(tmpname);
 	}
-      if (tmpname)
-        g_free (tmpname);
+      g_free (tmpname);
     }
 
   /* Fall back to gdk-pixbuf */
   if (pixbuf == NULL)
     {
-#ifdef HAVE_LIBJPEG
-      if (strcmp (mime_type, "image/jpeg") == 0)
-	pixbuf = _gnome_thumbnail_load_scaled_jpeg (uri, size, size);
-      else
-#endif
-	pixbuf = gnome_gdk_pixbuf_new_from_uri_at_scale (uri, size, size, TRUE);
+      pixbuf = gnome_gdk_pixbuf_new_from_uri_at_scale (uri, size, size, TRUE);
+
+      if (pixbuf != NULL)
+        {
+          original_width = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (pixbuf),
+                                                               "gnome-original-width"));
+          original_height = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (pixbuf),
+                                                                "gnome-original-height"));
+        }
     }
       
   if (pixbuf == NULL)
     return NULL;
 
-  width = gdk_pixbuf_get_width (pixbuf);
-  g_object_set_data_full (G_OBJECT (pixbuf), "gnome-thumbnail-width",
-			  g_strdup_printf ("%d", width), g_free);
-  height = gdk_pixbuf_get_height (pixbuf);
-  g_object_set_data_full (G_OBJECT (pixbuf), "gnome-thumbnail-height",
-			  g_strdup_printf ("%d", height), g_free);
+  /* The pixbuf loader may attach an "orientation" option to the pixbuf,
+     if the tiff or exif jpeg file had an orientation tag. Rotate/flip
+     the pixbuf as specified by this tag, if present. */
+  tmp_pixbuf = gdk_pixbuf_apply_embedded_orientation (pixbuf);
+  g_object_unref (pixbuf);
+  pixbuf = tmp_pixbuf;
 
+  width = gdk_pixbuf_get_width (pixbuf);
+  height = gdk_pixbuf_get_height (pixbuf);
+  
   if (width > size || height > size)
     {
+      const gchar *orig_width, *orig_height;
       scale = (double)size / MAX (width, height);
 
       scaled = gnome_thumbnail_scale_down_pixbuf (pixbuf,
 						  floor (width * scale + 0.5),
 						  floor (height * scale + 0.5));
 
+      orig_width = gdk_pixbuf_get_option (pixbuf, "tEXt::Thumb::Image::Width");
+      orig_height = gdk_pixbuf_get_option (pixbuf, "tEXt::Thumb::Image::Height");
+
+      if (orig_width != NULL) {
+	      gdk_pixbuf_set_option (scaled, "tEXt::Thumb::Image::Width", orig_width);
+      }
+      if (orig_height != NULL) {
+	      gdk_pixbuf_set_option (scaled, "tEXt::Thumb::Image::Height", orig_height);
+      }
+      
       g_object_unref (pixbuf);
       pixbuf = scaled;
     }
   
+  if (original_width > 0) {
+	  g_snprintf (dimension, sizeof (dimension), "%i", original_width);
+	  gdk_pixbuf_set_option (pixbuf, "tEXt::Thumb::Image::Width", dimension);
+  }
+  if (original_height > 0) {
+	  g_snprintf (dimension, sizeof (dimension), "%i", original_height);
+	  gdk_pixbuf_set_option (pixbuf, "tEXt::Thumb::Image::Height", dimension);
+  }
+
   return pixbuf;
 }
 
@@ -1098,7 +1132,7 @@ make_thumbnail_fail_dirs (GnomeThumbnailFactory *factory)
  * @factory: a #GnomeThumbnailFactory
  * @thumbnail: the thumbnail as a pixbuf 
  * @uri: the uri of a file
- * @original_mtime: the mime type of the file
+ * @original_mtime: the modification time of the original file 
  *
  * Saves @thumbnail at the right place. If the save fails a
  * failed thumbnail is written.
@@ -1117,7 +1151,7 @@ gnome_thumbnail_factory_save_thumbnail (GnomeThumbnailFactory *factory,
   unsigned char *digest;
   char *path, *md5, *file, *dir;
   char *tmp_path;
-  char *width, *height;
+  const char *width, *height;
   int tmp_fd;
   char mtime_str[21];
   gboolean saved_ok;
@@ -1169,18 +1203,29 @@ gnome_thumbnail_factory_save_thumbnail (GnomeThumbnailFactory *factory,
     }
   close (tmp_fd);
   
-  g_snprintf (mtime_str, 21, "%lu",  original_mtime);
-  width = g_object_get_data (G_OBJECT (thumbnail), "gnome-thumbnail-width");
-  height = g_object_get_data (G_OBJECT (thumbnail), "gnome-thumbnail-height");
-  saved_ok  = gdk_pixbuf_save (thumbnail,
-			       tmp_path,
-			       "png", NULL,
-			       "tEXt::Thumb::Image::Width", width,
-			       "tEXt::Thumb::Image::Height", height,
-			       "tEXt::Thumb::URI", uri,
-			       "tEXt::Thumb::MTime", mtime_str,
-			       "tEXt::Software", "GNOME::ThumbnailFactory",
-			       NULL);
+  g_snprintf (mtime_str, 21, "%ld",  original_mtime);
+  width = gdk_pixbuf_get_option (thumbnail, "tEXt::Thumb::Image::Width");
+  height = gdk_pixbuf_get_option (thumbnail, "tEXt::Thumb::Image::Height");
+
+  if (width != NULL && height != NULL) 
+    saved_ok  = gdk_pixbuf_save (thumbnail,
+				 tmp_path,
+				 "png", NULL,
+				 "tEXt::Thumb::Image::Width", width,
+				 "tEXt::Thumb::Image::Height", height,
+				 "tEXt::Thumb::URI", uri,
+				 "tEXt::Thumb::MTime", mtime_str,
+				 "tEXt::Software", "GNOME::ThumbnailFactory",
+				 NULL);
+  else
+    saved_ok  = gdk_pixbuf_save (thumbnail,
+				 tmp_path,
+				 "png", NULL,
+				 "tEXt::Thumb::URI", uri,
+				 "tEXt::Thumb::MTime", mtime_str,
+				 "tEXt::Software", "GNOME::ThumbnailFactory",
+				 NULL);
+    
 
   if (saved_ok)
     {
@@ -1220,7 +1265,7 @@ gnome_thumbnail_factory_save_thumbnail (GnomeThumbnailFactory *factory,
  * gnome_thumbnail_factory_create_failed_thumbnail:
  * @factory: a #GnomeThumbnailFactory
  * @uri: the uri of a file
- * @mtime: the mime type of the file
+ * @mtime: the modification time of the file
  *
  * Creates a failed thumbnail for the file so that we don't try
  * to re-thumbnail the file later.
@@ -1288,7 +1333,7 @@ gnome_thumbnail_factory_create_failed_thumbnail (GnomeThumbnailFactory *factory,
     }
   close (tmp_fd);
   
-  g_snprintf (mtime_str, 21, "%lu",  mtime);
+  g_snprintf (mtime_str, 21, "%ld",  mtime);
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1);
   saved_ok  = gdk_pixbuf_save (pixbuf,
 			       tmp_path,
